Received: from localhost (maia-2.hub.org [200.46.204.187]) by postgresql.org (Postfix) with ESMTP id 31EBF9FB940 for ; Mon, 4 Jun 2007 11:21:45 -0300 (ADT) Received: from postgresql.org ([200.46.204.71]) by localhost (mx1.hub.org [200.46.204.187]) (amavisd-maia, port 10024) with ESMTP id 45095-03 for ; Mon, 4 Jun 2007 11:21:38 -0300 (ADT) Received: from news.hub.org (news.hub.org [200.46.204.72]) by postgresql.org (Postfix) with ESMTP id 70E869FB831 for ; Mon, 4 Jun 2007 11:21:44 -0300 (ADT) Received: from news.hub.org (news.hub.org [200.46.204.72]) by news.hub.org (8.13.8/8.13.8) with ESMTP id l54ELZ2h080948 for ; Mon, 4 Jun 2007 11:21:35 -0300 (ADT) (envelope-from news@news.hub.org) Received: (from news@localhost) by news.hub.org (8.13.8/8.13.8/Submit) id l54ECf3Y049925 for pgsql-admin@postgresql.org; Mon, 4 Jun 2007 11:12:41 -0300 (ADT) (envelope-from news) From: "Charles.Hou" X-Newsgroups: pgsql.admin Subject: Auto Vacuum question? Date: Mon, 04 Jun 2007 07:12:48 -0700 Organization: http://groups.google.com Lines: 17 Message-ID: <1180966368.172224.250500@x35g2000prf.googlegroups.com> Mime-Version: 1.0 Content-Type: text/plain; charset="big5" X-Complaints-To: groups-abuse@google.com User-Agent: G2/1.0 X-HTTP-UserAgent: Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727),gzip(gfe),gzip(gfe) Complaints-To: groups-abuse@google.com Injection-Info: x35g2000prf.googlegroups.com; posting-host=61.223.215.8; posting-account=Mznd-A0AAABITZ14OcULoTm5bpaBaOsm To: pgsql-admin@postgresql.org X-Virus-Scanned: Maia Mailguard 1.0.1 X-Archive-Number: 200706/16 X-Sequence-Number: 25684 i set the auto vacuum option to enable. but my database size(hard- disk space) still increased from 420MB to 440MB in 8 hours. most of the operations in this database are the "Select" query command, just few of "Update or Insert". why it can be increased so strongly? after i executed the command " vaccumdb -f -z testdb", but the size just decreased 1 or 2MB... what's the problem? how to know which command(select,insert....) takes the hurge loading to database in this time? computer environment: System: Red Hat Enterprise 4 Postgresql Server: 8.0.13 count of client connected : about 100 pc